@@ -1,5 +1,5 @@
 import sys
-import rpyc
+from ghpythonremote import rpyc
 from rpyc.utils.server import OneShotServer
 
 
